@@ -41,10 +41,10 @@ class Select(AbstractStatement, Sqlable):
 
     @property
     def table(self):
-        if issubclass(self.select_from, Table):
-            return self.select_from
-        elif isinstance(self.select_from, Select):
+        if isinstance(self.select_from, Select):
             return self.select_from.table
+        elif isinstance(self.select_from, type) and issubclass(self.select_from, Table):
+            return self.select_from
         else:
             raise ValueError(f'unexpected {self.select_from=}')
 
